

# Demo-Chat: PyQT / Socket / Hash-Based MAC

A project that implements chat using sockets. Hash-Based Message Authentication Code is used for user authorization.

(RU) Проект реализующий чат с использованием сокетов. При авторизации пользователя используется "Hash-Based Message Authentication Code".

## Quick start

```bash

# 📀 install python-package
poetry add pyqtchat8741


# 📀 or (if you don't using poetry)
pip install pyqtchat8741

# 💾 create folder for db store
mkdir db

# 🚀 for execute CLI interface. After input "s" for start or "x" for exit
pyqtchat8741_start

# or

# 🚀 you can start sepparetly sever and clients
pyqtchat8741_server # run server
pyqtchat8741_client # run client
```
